@@ -300,12 +300,11 @@ class Registry(abc.ABC, metaclass=clu.abstract.Slotted):
     
     @classmethod
     def __init_subclass__(cls, appname=None, **kwargs):
-        if appname:
-            appnames.add(appname)
-        else:
+        if not appname:
             appname = determine_name(cls)
         if appname in classes:
             raise TypeError(f"appname already registered: {appname}")
+        appnames.add(appname)
         classes[appname] = cls
         super(Registry, cls).__init_subclass__(**kwargs) # type: ignore
         cls.instances = weakref.WeakValueDictionary()
@@ -543,6 +542,12 @@ class ExporterBase(collections.abc.MutableMapping,
             return self.__exports__.pop(key)
         return self.__exports__.pop(key, default)
     
+    def popitem(self):
+        """ Remove and return a single key-value pair, raising a KeyError
+            if the exporter is empty
+        """
+        return self.__exports__.popitem()
+    
     def update(self, dictish=NoDefault, **updates):
         """ Update the exporter with key/value pairs and/or an iterator;
             q.v. `dict.update(…)` docstring supra.
@@ -608,9 +613,11 @@ class ExporterBase(collections.abc.MutableMapping,
             if named is None:
                 raise ExportError(type(self).messages['noname'] % id(thing))
             
-            # Retrieve the things’ ostensible __name__ and __qualname__ attribute values:
+            # Retrieve the things’ ostensible __name__, __qualname__, and
+            # __code__ attribute values:
             dname = getattr(thing, '__name__')
             qname = getattr(target, '__qualname__')
+            fcode = getattr(target, '__code__', None)
             
             # ATTEMPT TO RENAME!!!…
             # VIA FULL-FLOW MULTI-STAGED COMBUSTION:
@@ -623,7 +630,14 @@ class ExporterBase(collections.abc.MutableMapping,
             except AttributeError:
                 pass
             
-            # Attempt Nº2: update __name__ and set __lambda_name__ if necessary –
+            # Attempt Nº2: update __code__.co_name, by replacing __code__:
+            try:
+                if fcode:
+                    target.__code__ = fcode.replace(co_name=named)
+            except AttributeError:
+                pass    
+            
+            # Attempt Nº3: update __name__ and set __lambda_name__ if necessary
             # …to recall the lambda’s genesis:
             try:
                 target.__name__ = named
@@ -631,7 +645,7 @@ class ExporterBase(collections.abc.MutableMapping,
             except AttributeError:
                 pass
             else:
-                # Only pursue the Nº3 attempt if Nº2 didn’t fail –
+                # Only pursue the Nº4 attempt if Nº3 didn’t fail –
                 # …reset __module__ for phi-types:
                 if dname == φ and self.dotpath is not None:
                     target.__module__ = str(self.dotpath)
@@ -884,13 +898,13 @@ def test():
         everything()
     
     @inline.runif(not consts.TEXTMATE)
-    def test_one():
+    def test_thismodule():
         """ Sanity-check “thismodule()” """
         assert thismodule() == 'clu.exporting'
     
     @inline
-    def test_two():
-        """ Check the “itermodule(…)” and “itermoduleids(…)” functions """
+    def test_itermodule_itermoduleids():
+        """ Test “itermodule(…)” and “itermoduleids(…)” """
         from clu.typology import iterlen
         
         assert iterlen(itermodule(consts)) == len(consts.__all__)
@@ -904,6 +918,41 @@ def test():
         idpairs = dict(zip(dir(consts), (id(getattr(consts, const)) for const in dir(consts))))
         assert idpairs == dict(itermoduleids(consts))
     
+    @inline
+    def test_modulespace():
+        """ Test the “Modulespace” shortcut class """
+        modspace = Modulespace()
+        import sys, os, io
+        
+        assert modspace.sys == sys
+        assert modspace.os == os
+        assert modspace.io == io
+    
+    @inline
+    def test_search_for_name():
+        """ Test “search_for_name(…)” """
+        from clu.testing import utils
+        inlinetester_name = search_for_name(utils.InlineTester)
+        assert utils.InlineTester.__name__ == inlinetester_name
+        bucket_name = search_for_name(utils.Bucket)
+        assert utils.Bucket.__name__ == bucket_name
+    
+    @inline
+    def test_search_for_module():
+        """ Test “search_for_module(…)” """
+        from clu.testing import utils
+        inlinetester_module = search_for_module(utils.InlineTester)
+        assert utils == inlinetester_module
+        bucket_module = search_for_module(utils.Bucket)
+        assert utils == bucket_module
+        format_environment_module = search_for_module(utils.format_environment)
+        assert utils == format_environment_module
+    
+    @inline.diagnostic
+    def show_search_by_id_cache_info():
+        print("SEARCH-BY-ID CACHE INFO:")
+        print(Exporter.cache_info())
+    
     return inline.test(100)
 
 if __name__ == '__main__':
