@@ -25,7 +25,7 @@ class TestVersion(object):
         
         vtags0 = git_version_tags()
         
-        if gitrun:
+        if vtags0:
             version = cluversion.to_string()
             assert vtags0 is not None
             assert vtags0.startswith(f'v{version}')
@@ -81,4 +81,4 @@ class TestVersion(object):
         assert version_info != VersionInfo(b'0.0.1')
         
         assert bool(version_info)
-        assert not bool(VersionInfo('‽.‽.‽'))
\ No newline at end of file
+        assert not bool(VersionInfo('‽.‽.‽'))
